package com.winhc.bigdata.spark.utils

import java.util.{Calendar, Date, Locale}

import org.apache.commons.lang3.time.DateFormatUtils
import org.apache.spark.sql.SparkSession

/**
 * @Author: XuJiakai
 * @Date: 2020/6/3 18:49
 * @Description:
 */
object BaseUtil {
  def isWindows: Boolean = System.getProperty("os.name").contains("Windows")

  def getPartitions(t: String, @transient spark: SparkSession): Seq[String] = {
    import spark._
    val sql_s = s"show partitions " + t
    sql(sql_s).collect.toList.map(_.getString(0).split("=")(1)).seq
  }

  def getPartion(t: String, @transient spark: SparkSession) = {
    val ps = getPartitions(t, spark)
    if (ps.length > 1) {
      ps.last
    } else {
      ""
    }
  }

  def getFirstPartion(t: String, @transient spark: SparkSession) = {
    val ps = getPartitions(t, spark)
    if (ps.length > 1) {
      ps.head
    } else {
      ""
    }
  }

  def atMonthsBefore(n: Int, pattern: String = "yyyy-MM-dd"): String = {
    val c = Calendar.getInstance(Locale.CHINA)
    c.setTimeInMillis(new Date().getTime)
    c.add(Calendar.MONTH, -1 * n)
    DateFormatUtils.format(c.getTime.getTime, pattern)
  }

  def atDaysAfter(n: Int, time: String, pattern: String = "yyyyMMdd"): String = {
    import java.text.SimpleDateFormat
    val newtime: Date = new SimpleDateFormat("yyyyMMdd").parse(time)
    val c = Calendar.getInstance(Locale.CHINA)
    c.setTimeInMillis(newtime.getTime)
    c.add(Calendar.DATE, 1 * n)
    DateFormatUtils.format(c.getTime.getTime, pattern)
  }
}
